@@ -1,5 +1,5 @@
 """
-An RFC 8771-compliant implementation of the Internationalized Deliberately Unreadable Network Notation (shortened as I-DUNNO)
+An RFC8771-compliant implementation of the Internationalized Deliberately Unreadable Network Notation (shortened as I-DUNNO)
 """
 
 
@@ -15,7 +15,7 @@ from . import data
 __all__ = ['encode', 'decode']
 
 
-__version__ = '0.1.1'
+__version__ = '0.1.3'
 
 
 utf8_lengths = [(0, 7), (8, 11), (12, 16), (17, 21)]
@@ -24,7 +24,7 @@ utf8_lengths = [(0, 7), (8, 11), (12, 16), (17, 21)]
 confusion_constraints = {
     'multi-octet': lambda bytestr: any(num >= 0b11000000 for num in bytestr),
     'disallowed': lambda bytestr: any(char in data.idna_disallowed for char in bytestr.decode('utf-8')),
-    'non-printable': lambda bytestr: not any(char.isprintable() for char in bytestr.decode('utf-8')),
+    'non-printable': lambda bytestr: any(not char.isprintable() for char in bytestr.decode('utf-8')),
     'multiple-scripts': lambda bytestr: len({data.character_script(char) for char in bytestr.decode('utf-8')}) > 1,
     'category-symbol': lambda bytestr: any(char in data.category_symbols for char in bytestr.decode('utf-8')),
     'multiple-directionalities': lambda bytestr: len({data.character_bidi(char) for char in bytestr.decode('utf-8')}) > 1,
@@ -112,7 +112,7 @@ def confusion_check(bytestr, level, levels, constraints):
     return satisfied >= confusion_level['required']
 
 
-def encode(addr, level='satisfactory'):
+def encode(addr, level='minimum'):
     """
     Encode an ipaddress.IPv6Address or an ipaddress.IPv4Address object into a random, valid I-DUNNO representation at the given confusion level.
     A ValueError is raised if valid I-DUNNO for the given arguments does not exist.
@@ -151,7 +151,7 @@ def decode(i_dunno):
                 bits += int_to_bits(num, length)
                 break
         else:
-            raise ValueError('invalid I-DUNNO notation')
+            raise ValueError('invalid I-DUNNO')
 
     addr = bits_to_bytes(bits)
 
@@ -160,7 +160,7 @@ def decode(i_dunno):
     elif len(addr) == 4:
         cls = ipaddress.IPv4Address
     else:
-        raise ValueError('invalid I-DUNNO notation')
+        raise ValueError('invalid I-DUNNO')
 
     try:
         return cls(addr)
